(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     17929,        422]
NotebookOptionsPosition[     17606,        407]
NotebookOutlinePosition[     17977,        423]
CellTagsIndexPosition[     17934,        420]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["A GENERALIZED DESIGN METHOD FOR DIRECTIVITY PATTERNS OF SPHERICAL \
MICROPHONE ARRAYS", "Title",
  FontSize->14],
 "\n\n",
 StyleBox["Enzo De Sena, H\[UDoubleDot]seyin Hac\[DotlessI]habibo\:011flu and \
Zoran Cvetkovic\nDepartment of Informatics, King' s College London Strand, \n\
WC2R 2 LS, London, United Kingdom\n{e.desena | zoran.cvetkovic}@kcl.ac.uk\n\
huseyin@hacihabiboglu.org",
  Editable->False,
  Deletable->False],
 "\n\n\n\n",
 StyleBox["To execute the notebook, please evaluate the following block of \
code (Shift + enter)", "Section",
  FontSize->16]
}], "Input",
 FormatType->"TextForm"],

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Lambda]", "=", "0.5"}], ",", 
     RowBox[{"\[Alpha]", "=", 
      RowBox[{"Pi", "/", "2"}]}], ",", 
     RowBox[{"\[Beta]", "=", "90"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[CapitalGamma]", "[", 
      RowBox[{"\[Theta]_", ",", "a1_"}], "]"}], "=", 
     RowBox[{"1", "-", "a1", "+", 
      RowBox[{"a1", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalGamma]1", "[", 
      RowBox[{"\[Theta]_", ",", "a1_"}], "]"}], "=", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"\[CapitalGamma]", "[", 
        RowBox[{"\[Theta]", ",", "a1"}], "]"}], ",", "\[Theta]"}], "]"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalPhi]1", "[", 
      RowBox[{"a1_", ",", "\[Alpha]_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"\[Theta]", ",", "a1"}], "]"}], "^", "2"}], 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]", ",", "\[Alpha]", ",", "Pi"}], "}"}]}], "]"}], 
      "/", 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"\[Theta]", ",", "a1"}], "]"}], "^", "2"}], 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]", ",", "0", ",", "\[Alpha]"}], "}"}]}], "]"}]}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalPhi]2", "[", 
      RowBox[{"a1_", ",", "\[Alpha]_"}], "]"}], "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[CapitalGamma]1", "[", 
          RowBox[{"\[Theta]", ",", "a1"}], "]"}], "^", "2"}], 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Theta]", ",", "0", ",", "\[Alpha]"}], "}"}]}], "]"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"a1_", ",", "\[Lambda]_", ",", "\[Alpha]_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"\[CapitalPhi]1", "[", 
        RowBox[{"a1", ",", "\[Alpha]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Lambda]"}], ")"}], "  ", 
       RowBox[{"\[CapitalPhi]2", "[", 
        RowBox[{"a1", ",", "\[Alpha]"}], "]"}]}]}]}], " ", ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"DirFactor", "[", "a1_", "]"}], "=", 
     RowBox[{"2", "/", 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalGamma]", "[", 
           RowBox[{"\[Theta]", ",", "a1"}], "]"}], "^", "2"}], 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Theta]", ",", "0", ",", "Pi"}], "}"}]}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"LogF", "[", "\[CapitalGamma]_", "]"}], "=", 
     RowBox[{
      RowBox[{"UnitStep", "[", 
       RowBox[{
        RowBox[{"20", 
         RowBox[{"Log", "[", 
          RowBox[{"10", ",", 
           RowBox[{"Abs", "[", "\[CapitalGamma]", "]"}]}], "]"}]}], "+", 
        "40"}], "]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"20", 
         RowBox[{"Log", "[", 
          RowBox[{"10", ",", 
           RowBox[{"Abs", "[", "\[CapitalGamma]", "]"}]}], "]"}]}], "+", 
        "40"}], ")"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    
    RowBox[{"Column", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Row", "[", 
        RowBox[{"{", 
         RowBox[{"Dynamic", "[", 
          RowBox[{
           RowBox[{"solution", "=", 
            RowBox[{
             RowBox[{"Minimize", "[", 
              RowBox[{
               RowBox[{"\[CapitalPhi]", "[", 
                RowBox[{"a1", ",", "\[Lambda]", ",", "\[Alpha]"}], "]"}], ",", 
               RowBox[{"{", "a1", "}"}]}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "]"}], "}"}], "]"}], 
       ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Panel", "[", 
        RowBox[{"Column", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Slider2D", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Dynamic", "[", "\[Alpha]", "]"}], ",", 
                  RowBox[{"Dynamic", "[", "\[Lambda]", "]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0.000001", ",", "0"}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"Pi", ",", "1"}], "}"}]}], "}"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}], ",", 
              RowBox[{"Column", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Row", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "\"\<  Set\[VeryThinSpace] \[Lambda] here: \>\"", ",", 
                    RowBox[{"Control", "[", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]", ",", "0", ",", "1"}], "}"}], "]"}], 
                    ",", "\"\<  Value of \[Lambda]: \>\"", ",", 
                    RowBox[{"Dynamic", "[", "\[Lambda]", "]"}]}], "}"}], 
                  "]"}], ",", 
                 RowBox[{"Row", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "\"\<  Set\[VeryThinSpace] \[Alpha] here: \>\"", ",", 
                    RowBox[{"Control", "[", 
                    RowBox[{"{", 
                    RowBox[{"\[Alpha]", ",", "0.000001", ",", "Pi"}], "}"}], 
                    "]"}], ",", "\"\<  Value of \[Alpha]: \>\"", ",", 
                    RowBox[{"Dynamic", "[", "\[Alpha]", "]"}]}], "}"}], 
                  "]"}]}], "}"}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Button", "[", 
               RowBox[{"\"\<Omnidirectional\>\"", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Lambda]", "=", "0"}], ",", 
                  RowBox[{"\[Alpha]", "=", "Pi"}]}], "}"}]}], "]"}], ",", 
              RowBox[{"Button", "[", 
               RowBox[{"\"\<Subcardioid\>\"", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Lambda]", "=", "0.5601928710937499"}], ",", 
                  RowBox[{"\[Alpha]", "=", "2.1902893066406253"}]}], "}"}]}], 
               "]"}], ",", 
              RowBox[{"Button", "[", 
               RowBox[{"\"\<Cardioid\>\"", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Lambda]", "=", "0.5066226196289062"}], ",", 
                  RowBox[{"\[Alpha]", "=", "1.6957782745361332"}]}], "}"}]}], 
               "]"}], ",", 
              RowBox[{"Button", "[", 
               RowBox[{"\"\<Supercardioid\>\"", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Lambda]", "=", "1"}], ",", 
                  RowBox[{"\[Alpha]", "=", 
                   RowBox[{"N", "[", 
                    RowBox[{"Pi", "/", "2"}], "]"}]}]}], "}"}]}], "]"}], ",", 
              
              RowBox[{"Button", "[", 
               RowBox[{"\"\<Hypercardioid\>\"", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Lambda]", "=", "1"}], ",", 
                  RowBox[{"\[Alpha]", "=", "0.000001"}]}], "}"}]}], "]"}]}], 
             "}"}], "]"}], ",", "\[IndentingNewLine]", 
           "\"\<______________________________________________________________\
____________________________________\>\"", ",", "\[IndentingNewLine]", 
           "\"\<\>\"", ",", "\[IndentingNewLine]", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<Coefficients: \>\"", ",", " ", 
              RowBox[{"Dynamic", "[", "solution", "]"}]}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<Spherical harmonics coefficients: \>\"", ",", " ", 
              RowBox[{"Dynamic", "[", 
               RowBox[{"N", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"b0", "\[Rule]", 
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "a1"}], ")"}], " ", 
                    SqrtBox["\[Pi]"]}]}], ",", 
                    RowBox[{"b1", "\[Rule]", 
                    RowBox[{"2", " ", "a1", " ", 
                    SqrtBox[
                    FractionBox["\[Pi]", "3"]]}]}]}], "}"}], "}"}], "/.", 
                 "solution"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<Front-back ratio: \>\"", ",", 
              RowBox[{"Dynamic", "[", " ", 
               RowBox[{"10", 
                RowBox[{"Log", "[", 
                 RowBox[{"10", ",", 
                  RowBox[{"1", "/", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[CapitalPhi]1", "[", 
                    RowBox[{"a1", ",", 
                    RowBox[{"Pi", "/", "2"}]}], "]"}], "/.", " ", 
                    "solution"}], ")"}]}]}], "]"}]}], "]"}]}], "}"}], "]"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<Directivity index: \>\"", ",", 
              RowBox[{"Dynamic", "[", " ", 
               RowBox[{"10", 
                RowBox[{"Log", "[", 
                 RowBox[{"10", ",", 
                  RowBox[{
                   RowBox[{"DirFactor", "[", "a1", "]"}], "/.", " ", 
                   "solution"}]}], "]"}]}], "]"}]}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<The level at \>\"", ",", 
              RowBox[{"Slider", "[", 
               RowBox[{
                RowBox[{"Dynamic", "[", "\[Beta]", "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "180"}], "}"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
              "\"\< \>\"", ",", " ", 
              RowBox[{"Dynamic", "[", "\[Beta]", "]"}], ",", 
              "\"\< degrees is: \>\"", ",", 
              RowBox[{"Dynamic", "[", 
               RowBox[{"20", 
                RowBox[{"Log", "[", 
                 RowBox[{"10", ",", 
                  RowBox[{"Abs", "[", 
                   RowBox[{
                    RowBox[{"\[CapitalGamma]", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[Beta]", "/", "180"}], "*", "Pi"}], ",", "a1"}],
                     "]"}], "/.", "solution"}], "]"}]}], "]"}]}], "]"}]}], 
             "}"}], "]"}], ",", "\[IndentingNewLine]", "\"\<\>\"", ",", 
           "\[IndentingNewLine]", 
           "\"\<Amplitude plot on the left. The same plot with dB scale (the \
center is at <40dB) is on the right.\>\"", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Dynamic", "[", 
             RowBox[{"PolarPlot", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{"\[CapitalGamma]", "[", 
                    RowBox[{"\[Theta]", ",", "a1"}], "]"}], "/.", 
                   "solution"}], "]"}], ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Theta]", ",", "0", ",", 
                 RowBox[{"2", "Pi"}]}], "}"}], ",", 
               RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
               RowBox[{"PlotStyle", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Directive", "[", 
                   RowBox[{"Thick", ",", "Blue"}], "]"}], ",", "Gray"}], 
                 "}"}]}]}], "]"}], "]"}], "\[IndentingNewLine]", 
            RowBox[{"Dynamic", "[", 
             RowBox[{"PolarPlot", "[", 
              RowBox[{
               RowBox[{"{", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"LogF", "[", 
                  RowBox[{
                   RowBox[{"\[CapitalGamma]", "[", 
                    RowBox[{"\[Theta]", ",", "a1"}], "]"}], "/.", 
                   "solution"}], "]"}], ",", "40"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Theta]", ",", "0", ",", 
                 RowBox[{"2", "Pi"}]}], "}"}], ",", 
               RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
               RowBox[{"PlotStyle", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Directive", "[", 
                   RowBox[{"Thick", ",", "Blue"}], "]"}], ",", "Gray"}], 
                 "}"}]}]}], "]"}], "]"}]}]}], "}"}], "]"}], "]"}]}], "}"}], 
     "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.488296762053659*^9, 3.4882968194521008`*^9}, {
   3.495622773463846*^9, 3.495622782587138*^9}, {3.496147357177004*^9, 
   3.4961474205478373`*^9}, {3.496147512849291*^9, 3.496147537312481*^9}, {
   3.496928477040997*^9, 3.496928512949757*^9}, {3.4969285718532667`*^9, 
   3.4969287371340723`*^9}, {3.497007424536797*^9, 3.497007486083469*^9}, {
   3.497007523205421*^9, 3.497007536675029*^9}, 3.49700757151122*^9, {
   3.497007607963326*^9, 3.497007611576333*^9}, 3.497007666817582*^9, {
   3.4970077125946503`*^9, 3.4970077166335287`*^9}, {3.497007757225767*^9, 
   3.4970077675508757`*^9}, {3.4970088754658947`*^9, 3.497008978745824*^9}, {
   3.4970090094749413`*^9, 3.4970090516471*^9}, {3.497009205466442*^9, 
   3.497009252940013*^9}, {3.4970093358854437`*^9, 3.497009360643937*^9}, {
   3.4970096242981253`*^9, 3.497009746524068*^9}, {3.497009791222559*^9, 
   3.497009841160474*^9}, {3.497010001034914*^9, 3.497010008870351*^9}, {
   3.497010168310343*^9, 3.497010258324175*^9}, {3.497010474160904*^9, 
   3.497010474611384*^9}, 3.4970105073317127`*^9, {3.4970107605699177`*^9, 
   3.497010806364933*^9}, {3.497010970310193*^9, 3.4970109712292*^9}, {
   3.497011167825366*^9, 3.497011249310828*^9}, {3.497011279710127*^9, 
   3.497011282333716*^9}, {3.49707854706201*^9, 3.497078594757039*^9}, {
   3.497078638406877*^9, 3.497078678283927*^9}, {3.497078708530966*^9, 
   3.4970787125406933`*^9}, {3.49707878918512*^9, 3.497078871372088*^9}, {
   3.4970794159811983`*^9, 3.497079560893573*^9}, {3.497079649280459*^9, 
   3.497079706724975*^9}, 3.497079753766631*^9, {3.497079794593903*^9, 
   3.4970798197477617`*^9}, {3.497079857433674*^9, 3.4970798614728413`*^9}, {
   3.497083712968535*^9, 3.497083713398636*^9}, {3.497084367757936*^9, 
   3.4970843707837687`*^9}, {3.497084710492675*^9, 3.4970847122836723`*^9}, {
   3.4970848466751547`*^9, 3.497084852593158*^9}, {3.497084907437173*^9, 
   3.497084934985427*^9}, {3.497084968687264*^9, 3.497084970043295*^9}, {
   3.4970852303407707`*^9, 3.497085251831337*^9}, {3.4970853013001947`*^9, 
   3.497085437845922*^9}, {3.497089933377968*^9, 3.497089967840268*^9}, {
   3.497090048175226*^9, 3.4970902446110373`*^9}, {3.4970903116466417`*^9, 
   3.497090314465828*^9}, {3.4970903487286654`*^9, 3.497090363810347*^9}, {
   3.4971728835372677`*^9, 3.49717305055982*^9}, {3.497173094846156*^9, 
   3.497173103346447*^9}, {3.497173135659135*^9, 3.497173243443768*^9}, {
   3.497173275953002*^9, 3.49717327674936*^9}, {3.4971733512865057`*^9, 
   3.497173359735344*^9}, {3.497175027308585*^9, 3.497175048581911*^9}, {
   3.4971772250341187`*^9, 3.4971772264473124`*^9}, {3.497177320316626*^9, 
   3.497177435157262*^9}, {3.497177548960683*^9, 3.49717755323547*^9}, {
   3.497177612249504*^9, 3.4971776146601*^9}, {3.4972215551040983`*^9, 
   3.497221559428452*^9}}]
},
AutoGeneratedPackage->None,
WindowSize->{1085, 788},
WindowMargins->{{Automatic, 24}, {-158, Automatic}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 631, 16, 164, "Input"],
Cell[1179, 38, 16423, 367, 578, "Input"]
}
]
*)

(* End of internal cache information *)
